@@ -53,7 +53,6 @@ DEFAULT_LOG_LEVELS <- c("fatal", "error", "warn", "info", "debug", "trace")
 #' get_log_levels()
 #' remove_log_levels("errorish")
 #' get_log_levels()
-#'
 get_log_levels <- function(){
   getOption("lgr.log_levels")
 }
@@ -221,6 +220,16 @@ standardize_threshold <- function(
 
 
 
+is_threshold <- function(x){
+  tryCatch(
+    {standardize_threshold(x); TRUE},
+    error = function(...) FALSE
+  )
+}
+
+
+
+
 standardize_log_level <- function(
   x,
   log_levels = getOption("lgr.log_levels")
@@ -241,6 +250,16 @@ standardize_log_level <- function(
 
 
 
+is_log_level <- function(x){
+  tryCatch(
+    {standardize_log_level(x); TRUE},
+    error = function(...) FALSE
+  )
+}
+
+
+
+
 standardize_log_levels <- function(
   x,
   log_levels = getOption("lgr.log_levels")
@@ -260,6 +279,16 @@ standardize_log_levels <- function(
 
 
 
+is_log_levels <- function(x){
+  tryCatch(
+    {standardize_log_levels(x); TRUE},
+    error = function(...) FALSE
+  )
+}
+
+
+
+
 error_msg_log_levels <- function(varname, log_levels){
   ll_text <-
     paste(sprintf("%s (%s)", names(log_levels), log_levels), collapse = ", ")
@@ -291,11 +320,10 @@ error_msg_log_levels <- function(varname, log_levels){
 #' @family formatting utils
 #' @export
 #' @examples
-#'
 #' x <- label_levels(c(seq(0, 600, by = 100), NA))
 #' print(x)
 #' unlabel_levels(x)
-#'
+
 label_levels <- function(
   levels,
   log_levels = getOption("lgr.log_levels")
